@@ -1,6 +1,8 @@
 from FHmonitor.monitor import Monitor
 import pytest
 from FHmonitor.store import MongoDB
+from FHmonitor.atm90_e32_pi import ATM90e32
+from FHmonitor.calibrate import Calibrate
 import logging
 logging.basicConfig(level=logging.DEBUG)
 
@@ -34,3 +36,8 @@ def test_store_reading(meter, store):
     reading = {"Pa": Pa, "Pr": Pr, }
     result = store.save(reading)
     assert result is True
+
+
+def test_calibrate_voltage():
+    c = Calibrate()
+    assert c.lineFreq > 0
